pub struct ChatMLTemplate;Expand description
ChatML template format (default).
<|im_start|>system
{system_prompt}<|im_end|>
<|im_start|>user
{message}<|im_end|>
<|im_start|>assistantTrait Implementations
Sourceimpl ChatTemplate for ChatMLTemplate
impl ChatTemplate for ChatMLTemplate
Sourcefn format(
&self,
system_prompt: &str,
messages: &[Message],
tools: &[ToolSchema],
) -> String
fn format( &self, system_prompt: &str, messages: &[Message], tools: &[ToolSchema], ) -> String
Format a complete prompt from system prompt, messages, and tools.
Sourcefn format_system(&self, system_prompt: &str, tools: &[ToolSchema]) -> String
fn format_system(&self, system_prompt: &str, tools: &[ToolSchema]) -> String
Format the system block (system prompt + tool definitions).
Sourcefn format_message(&self, message: &Message) -> String
fn format_message(&self, message: &Message) -> String
Wrap a single conversation message in template markers.
Returns empty string for system messages (handled by
format_system).Sourcefn assistant_prefix(&self) -> &str
fn assistant_prefix(&self) -> &str
The string appended after all messages to open the assistant’s turn.